@@ -1,5 +1,4 @@
 import numpy as np
-import re
 import time
 import trimesh
 from pykin.utils import plot_utils as p_utils
@@ -84,10 +83,7 @@ def convert_string_to_narray(str_input):
     Returns:
         np.array: Returns string to np.array
     """
-    if str_input is not None:
-        str_list = re.split(' |, ', str_input)
-        return np.array([float(data) for data in str_list])
-
+    return np.array([float(data) for data in str_input.split()])
 
 def calc_pose_error(tar_pose, cur_pose, EPS):
     """
@@ -175,20 +171,44 @@ def apply_objects_to_scene(trimesh_scene=None, objs=None):
 
     return trimesh_scene
 
-def apply_gripper_to_scene(trimesh_scene=None, robot=None):
+def apply_gripper_to_scene(trimesh_scene=None, robot=None, geom="collision"):
     if trimesh_scene is None:
         trimesh_scene = trimesh.Scene()
 
     for link, info in robot.gripper.info.items():
-        if info[1] == 'mesh':
-            mesh_color = p_utils.get_mesh_color(robot, link, 'collision')
-            if len(info) > 4 :
-                mesh_color = info[4]
-            mesh = info[2]
-            h_mat= info[3]
-            mesh.visual.face_colors = mesh_color
-            trimesh_scene.add_geometry(mesh, transform=h_mat)
+        mesh = info[2]
+        h_mat= info[3]
 
+        if link == "collision_pad":
+            continue
+        
+        if info[1] == 'mesh':
+            for idx, mesh in enumerate(info[2]):
+                mesh_color = p_utils.get_mesh_color(robot, link, geom, idx=idx)
+                if len(info) > 4 :
+                    mesh_color = info[4]
+                mesh.visual.face_colors = mesh_color
+                trimesh_scene.add_geometry(mesh, transform=h_mat)
+        if info[1] == "box":
+            for idx, param in enumerate(info[2]):
+                box_mesh = trimesh.creation.box(extents=param)
+                box_color = p_utils.get_mesh_color(robot, link, geom, idx)
+                box_mesh.visual.face_colors = box_color
+                trimesh_scene.add_geometry(box_mesh, transform=h_mat)
+
+        if info[1] == "cylinder":
+            for idx, param in enumerate(info[2]):
+                capsule_mesh = trimesh.creation.cylinder(height=param[0], radius=param[1])
+                capsule_color = p_utils.get_mesh_color(robot, link, geom, idx)
+                capsule_mesh.visual.face_colors = capsule_color
+                trimesh_scene.add_geometry(capsule_mesh, transform=h_mat)
+
+        if info[1] == "sphere":
+            for idx, param in enumerate(info[2]):
+                sphere_mesh = trimesh.creation.icosphere(radius=param)
+                sphere_color = p_utils.get_mesh_color(robot, link, geom, idx)
+                sphere_mesh.visual.face_colors = sphere_color
+                trimesh_scene.add_geometry(sphere_mesh, transform=h_mat)
     return trimesh_scene
 
 def apply_robot_to_scene(trimesh_scene=None, robot=None, geom="collision"):
@@ -200,31 +220,31 @@ def apply_robot_to_scene(trimesh_scene=None, robot=None, geom="collision"):
         h_mat = info[3]
         
         if info[1] == "mesh":
-            for mesh in info[2]:
-                mesh_color = p_utils.get_mesh_color(robot, link, geom)
+            for idx, mesh in enumerate(info[2]):
+                mesh_color = p_utils.get_mesh_color(robot, link, geom, idx)
                 if len(info) > 4:
                     mesh_color = info[4]
                 mesh.visual.face_colors = mesh_color
                 trimesh_scene.add_geometry(mesh, transform=h_mat)
     
         if info[1] == "box":
-            for param in info[2]:
+            for idx, param in enumerate(info[2]):
                 box_mesh = trimesh.creation.box(extents=param)
-                box_color = p_utils.get_mesh_color(robot, link, geom)
+                box_color = p_utils.get_mesh_color(robot, link, geom, idx)
                 box_mesh.visual.face_colors = box_color
                 trimesh_scene.add_geometry(box_mesh, transform=h_mat)
 
         if info[1] == "cylinder":
-            for param in info[2]:
+            for idx, param in enumerate(info[2]):
                 capsule_mesh = trimesh.creation.cylinder(height=param[0], radius=param[1])
-                capsule_color = p_utils.get_mesh_color(robot, link, geom)
+                capsule_color = p_utils.get_mesh_color(robot, link, geom, idx)
                 capsule_mesh.visual.face_colors = capsule_color
                 trimesh_scene.add_geometry(capsule_mesh, transform=h_mat)
 
         if info[1] == "sphere":
-            for param in info[2]:
+            for idx, param in enumerate(info[2]):
                 sphere_mesh = trimesh.creation.icosphere(radius=param)
-                sphere_color = p_utils.get_mesh_color(robot, link, geom)
+                sphere_color = p_utils.get_mesh_color(robot, link, geom, idx)
                 sphere_mesh.visual.face_colors = sphere_color
                 trimesh_scene.add_geometry(sphere_mesh, transform=h_mat)
     return trimesh_scene
